BatchPlanNodeMetadata

Trait BatchPlanNodeMetadata 

pub trait BatchPlanNodeMetadata: PhysicalPlanRef {
    // Required method
    fn order(&self) -> &Order;

    // Provided method
    fn orders(&self) -> Vec<Order> { ... }
}
A subtrait of PhysicalPlanRef for batch plans.

Due to the lack of refactoring, all plan nodes currently implement this trait through super::PlanBase. One may still use this trait as a bound for accessing a batch plan, in contrast to GenericPlanRef or PhysicalPlanRef.

Required Methods

fn order(&self) -> &Order

Provided Methods

fn orders(&self) -> Vec<Order>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T: 'a + BatchPlanNodeMetadata + ?Sized> BatchPlanNodeMetadata for &'a T

Source

fn order(&self) -> &Order

Source

fn orders(&self) -> Vec<Order>

Implementors

Source

impl BatchPlanNodeMetadata for BatchPlanRef

Allow access to all fields defined in BatchPlanNodeMetadata for the type-erased plan node.

Source

impl BatchPlanNodeMetadata for PlanBase<Batch>