StreamPlanNodeMetadata

Trait StreamPlanNodeMetadata 

pub trait StreamPlanNodeMetadata: PhysicalPlanRef {
    // Required methods
    fn stream_kind(&self) -> StreamKind;
    fn emit_on_window_close(&self) -> bool;
    fn watermark_columns(&self) -> &WatermarkColumns;
    fn columns_monotonicity(&self) -> &MonotonicityMap;

    // Provided method
    fn append_only(&self) -> bool { ... }
}
A subtrait of PhysicalPlanRef for stream plans.

Due to the lack of refactoring, all plan nodes currently implement this trait through super::PlanBase. One may still use this trait as a bound for accessing a stream plan, in contrast to GenericPlanRef or PhysicalPlanRef.

Required Methods

Provided Methods

fn append_only(&self) -> bool

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T: 'a + StreamPlanNodeMetadata + ?Sized> StreamPlanNodeMetadata for &'a T

Implementors

Source

impl StreamPlanNodeMetadata for PlanBase<Stream>

Source

impl StreamPlanNodeMetadata for StreamPlanRef

Allow access to all fields defined in StreamPlanNodeMetadata for the type-erased plan node.