pub trait BatchPlanNode:
PlanNodeCommon<Batch>
+ ToDistributedBatch
+ ToLocalBatch
+ TryToBatchPb { }Implementations
Sourceimpl dyn BatchPlanNode
impl dyn BatchPlanNode
Sourcepub fn is<__T: BatchPlanNode>(&self) -> bool
pub fn is<__T: BatchPlanNode>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast<__T: BatchPlanNode>(
self: Box<Self>,
) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: BatchPlanNode>( self: Box<Self>, ) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
Sourcepub fn downcast_rc<__T: BatchPlanNode>(
self: Rc<Self>,
) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: BatchPlanNode>( self: Rc<Self>, ) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: BatchPlanNode>(&self) -> Option<&__T>
pub fn downcast_ref<__T: BatchPlanNode>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
Sourcepub fn downcast_mut<__T: BatchPlanNode>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: BatchPlanNode>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.
Sourceimpl dyn BatchPlanNode
Directly implement methods for PlanNode to access the fields defined in GenericPlanRef.
impl dyn BatchPlanNode
Directly implement methods for PlanNode to access the fields defined in GenericPlanRef.
pub fn id(&self) -> PlanNodeId
pub fn ctx(&self) -> OptimizerContextRef
pub fn schema(&self) -> &Schema
pub fn stream_key(&self) -> Option<&[usize]>
pub fn functional_dependency(&self) -> &FunctionalDependencySet
pub fn explain_myself_to_string(&self) -> String
Sourceimpl dyn BatchPlanNode
impl dyn BatchPlanNode
Sourcepub fn to_batch_prost(&self) -> Result<PbBatchPlan, SchedulerError>
pub fn to_batch_prost(&self) -> Result<PbBatchPlan, SchedulerError>
Serialize the plan node and its children to a batch plan proto.
Sourcepub fn to_batch_prost_identity(
&self,
identity: bool,
) -> Result<PbBatchPlan, SchedulerError>
pub fn to_batch_prost_identity( &self, identity: bool, ) -> Result<PbBatchPlan, SchedulerError>
Serialize the plan node and its children to a batch plan proto without the identity field (for testing).
Sourceimpl dyn BatchPlanNode
impl dyn BatchPlanNode
pub fn as_batch_simple_agg(&self) -> Option<&BatchSimpleAgg>
pub fn as_batch_hash_agg(&self) -> Option<&BatchHashAgg>
pub fn as_batch_sort_agg(&self) -> Option<&BatchSortAgg>
pub fn as_batch_project(&self) -> Option<&BatchProject>
pub fn as_batch_filter(&self) -> Option<&BatchFilter>
pub fn as_batch_insert(&self) -> Option<&BatchInsert>
pub fn as_batch_delete(&self) -> Option<&BatchDelete>
pub fn as_batch_update(&self) -> Option<&BatchUpdate>
pub fn as_batch_seq_scan(&self) -> Option<&BatchSeqScan>
pub fn as_batch_sys_seq_scan(&self) -> Option<&BatchSysSeqScan>
pub fn as_batch_log_seq_scan(&self) -> Option<&BatchLogSeqScan>
pub fn as_batch_hash_join(&self) -> Option<&BatchHashJoin>
pub fn as_batch_nested_loop_join(&self) -> Option<&BatchNestedLoopJoin>
pub fn as_batch_values(&self) -> Option<&BatchValues>
pub fn as_batch_sort(&self) -> Option<&BatchSort>
pub fn as_batch_exchange(&self) -> Option<&BatchExchange>
pub fn as_batch_limit(&self) -> Option<&BatchLimit>
pub fn as_batch_top_n(&self) -> Option<&BatchTopN>
pub fn as_batch_hop_window(&self) -> Option<&BatchHopWindow>
pub fn as_batch_table_function(&self) -> Option<&BatchTableFunction>
pub fn as_batch_expand(&self) -> Option<&BatchExpand>
pub fn as_batch_lookup_join(&self) -> Option<&BatchLookupJoin>
pub fn as_batch_project_set(&self) -> Option<&BatchProjectSet>
pub fn as_batch_union(&self) -> Option<&BatchUnion>
pub fn as_batch_group_top_n(&self) -> Option<&BatchGroupTopN>
pub fn as_batch_source(&self) -> Option<&BatchSource>
pub fn as_batch_over_window(&self) -> Option<&BatchOverWindow>
pub fn as_batch_max_one_row(&self) -> Option<&BatchMaxOneRow>
pub fn as_batch_kafka_scan(&self) -> Option<&BatchKafkaScan>
pub fn as_batch_iceberg_scan(&self) -> Option<&BatchIcebergScan>
pub fn as_batch_file_scan(&self) -> Option<&BatchFileScan>
pub fn as_batch_postgres_query(&self) -> Option<&BatchPostgresQuery>
pub fn as_batch_my_sql_query(&self) -> Option<&BatchMySqlQuery>
pub fn as_batch_get_channel_delta_stats( &self, ) -> Option<&BatchGetChannelDeltaStats>
pub fn as_batch_vector_search(&self) -> Option<&BatchVectorSearch>