pub trait ToLocalBatch {
// Required method
fn to_local(&self) -> Result<BatchPlanRef>;
// Provided method
fn to_local_with_order_required(
&self,
required_order: &Order,
) -> Result<BatchPlanRef> { ... }
}Expand description
Converts a batch physical plan to local plan for local execution.
This is quite similar to ToBatch, but different in several ways. For example it converts
scan to exchange + scan.
Required Methods
fn to_local(&self) -> Result<BatchPlanRef>
Provided Methods
Sourcefn to_local_with_order_required(
&self,
required_order: &Order,
) -> Result<BatchPlanRef>
fn to_local_with_order_required( &self, required_order: &Order, ) -> Result<BatchPlanRef>
Convert the plan to batch local physical plan and satisfy the required Order
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".