pub(crate) fn plan_can_use_background_ddl(plan: &StreamPlanRef) -> boolExpand description
Check that all leaf nodes support recoverable background DDL.
pub(crate) fn plan_can_use_background_ddl(plan: &StreamPlanRef) -> boolCheck that all leaf nodes support recoverable background DDL.