LogicalCardinalityExt

Trait LogicalCardinalityExt 

pub trait LogicalCardinalityExt {
    // Required methods
    fn max_one_row(&self) -> bool;
    fn row_count(&self) -> Option<usize>;
}

Required Methods

fn max_one_row(&self) -> bool

Returns true if the plan node is guaranteed to yield at most one row.

fn row_count(&self) -> Option<usize>

Returns the number of rows the plan node is guaranteed to yield, if known exactly.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors