pub type BatchOptimizedLogicalPlanRoot = PlanRoot<PlanPhaseBatchOptimizedLogical>;Aliased Type
pub struct BatchOptimizedLogicalPlanRoot {
pub plan: PlanRef<Logical>,
_phase: PhantomData<PlanPhaseBatchOptimizedLogical>,
required_dist: RequiredDist,
required_order: Order,
out_fields: FixedBitSet,
out_names: Vec<String>,
}Fields
plan: PlanRef<Logical>_phase: PhantomData<PlanPhaseBatchOptimizedLogical>required_dist: RequiredDistrequired_order: Orderout_fields: FixedBitSetout_names: Vec<String>Implementations
Sourceimpl BatchOptimizedLogicalPlanRoot
impl BatchOptimizedLogicalPlanRoot
Sourcefn reject_variant_keys(&self) -> Result<()>
fn reject_variant_keys(&self) -> Result<()>
Rejects VARIANT wherever a batch plan would group, deduplicate or order by it. See
crate::optimizer::variant_key for why this is batch’s last line of defense.
Sourcepub fn gen_batch_plan(self) -> Result<BatchPlanRoot>
pub fn gen_batch_plan(self) -> Result<BatchPlanRoot>
Optimize and generate a singleton batch physical plan without exchange nodes.