fn get_col_indices_to_insert(
cols_to_insert_in_table: &[ColumnCatalog],
cols_to_insert_by_user: &[Ident],
table_name: &str,
) -> Result<(Vec<usize>, Vec<usize>)>Expand description
Parameters
-
cols_to_insert_in_table: the list of columns that are visible and non-generated -
cols_to_insert_by_user: The list of column identifiers explicitly specified by the user in the INSERT statement. -
table_name: The name of the target table.
Return
-
(col_indices_to_insert, default_column_indices)-
col_indices_to_insert: Column indices corresponding to user-specified columns in the INSERT statement, preserving the user-defined order. -
default_column_indices: Column indices of remaining columns in the target table that are not explicitly provided by the user and should be filled with DEFAULT values.
-