fn collect_scanned_relation_ids(
session: &SessionImpl,
plan: StreamPlanRef,
) -> HashMap<RelationId, HashSet<RelationId>>Expand description
Collect a mapping from bindable relation IDs to relation IDs actually scanned in the plan.
Index selection may replace a scan on a base table with a scan on one of its index tables. In that case, both the base table ID and the index table ID map to the actual index table ID, so a user can still specify the base table in a fixed backfill order.