pub trait PlanPhase {
type Convention: ConventionMarker;
}Expand description
PlanPhase is used to track the phase of the PlanRoot.
Usually, it begins from Logical and ends with Batch or Stream, unless we want to construct a PlanRoot from an intermediate phase.
Typical phase transformation are:
Logical->OptimizedLogicalForBatch->BatchLogical->OptimizedLogicalForStream->Stream
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".